<?php
// Version: 2.0 RC1; index

/*	This template is, perhaps, the most important template in the theme. It
	contains the main template layer that displays the header and footer of
	the forum, namely with main_above and main_below. It also contains the
	menu sub template, which appropriately displays the menu; the init sub
	template, which is there to set the theme up; (init can be missing.) and
	the linktree sub template, which sorts out the link tree.

	The init sub template should load any data and set any hardcoded options.

	The main_above sub template is what is shown above the main content, and
	should contain anything that should be shown up there.

	The main_below sub template, conversely, is shown after the main content.
	It should probably contain the copyright statement and some other things.

	The linktree sub template should display the link tree, using the data
	in the $context['linktree'] variable.

	The menu sub template should display all the relevant buttons the user
	wants and or needs.

	For more information on the templating system, please see the site at:
	http://www.simplemachines.org/
*/

// Initialize the template... mainly little settings.
function template_init()
{
	global $context, $settings, $options, $txt;

	/* Use images from default theme when using templates from the default theme?
		if this is 'always', images from the default theme will be used.
		if this is 'defaults', images from the default theme will only be used with default templates.
		if this is 'never' or isn't set at all, images from the default theme will not be used. */
	$settings['use_default_images'] = 'never';

	/* What document type definition is being used? (for font size and other issues.)
		'xhtml' for an XHTML 1.0 document type definition.
		'html' for an HTML 4.01 document type definition. */
	$settings['doctype'] = 'xhtml';

	/* The version this template/theme is for.
		This should probably be the version of SMF it was created for. */
	$settings['theme_version'] = '2.0 RC1';

	/* Set a setting that tells the theme that it can render the tabs. */
	$settings['use_tabs'] = true;

	/* Use plain buttons - as oppossed to text buttons? */
	$settings['use_buttons'] = true;

	/* Show sticky and lock status separate from topic icons? */
	$settings['separate_sticky_lock'] = true;

	/* Does this theme use the strict doctype? */
	$settings['strict_doctype'] = false;

	/* Does this theme use post previews on the message index? */
	$settings['message_index_preview'] = false;
	
	/* Set the following variable to true if this theme requires the optional theme strings file to be loaded. */
	$settings['require_theme_strings'] = true;



}

// The main sub template above the content.
function template_html_above()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	// Show right to left and the character set for ease of translating.
	echo '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
	<html xmlns="http://www.w3.org/1999/xhtml"', $context['right_to_left'] ? ' dir="rtl"' : '', '><head>
	<meta http-equiv="Content-Type" content="text/html; charset=', $context['character_set'], '" />
	<meta name="description" content="', $context['page_title_html_safe'], '" />
	<meta name="keywords" content="', $context['meta_keywords'], '" />
	<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/scripts/script.js?rc1"></script>
	<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/scripts/theme.js?rc1"></script>

	<script type="text/javascript" src="', $settings['theme_url'], '/bin/jquery.js?rc1"></script>
	<script type="text/javascript" src="', $settings['theme_url'], '/bin/jquery.jqDock.js?rc1"></script>
  <script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
  jQuery(function($){
    $("div.shortie").each(function(){ 
        var opts = { align:"center" , size:32, distance:80, coefficient:1.5, labels:"ml", duration:100 };
        $(this).jqDock(opts);
      });
  });
  	// ]]></script>

	
	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
		var smf_theme_url = "', $settings['theme_url'], '";
		var smf_default_theme_url = "', $settings['default_theme_url'], '";
		var smf_images_url = "', $settings['images_url'], '";
		var smf_scripturl = "', $scripturl, '";
		var smf_iso_case_folding = ', $context['server']['iso_case_folding'] ? 'true' : 'false', ';
		var smf_charset = "', $context['character_set'], '";', $context['show_pm_popup'] ? '
		if (confirm("' . $txt['show_personal_messages'] . '"))
			window.open(smf_prepareScriptUrl(smf_scripturl) + "action=pm");' : '', '
		var ajax_notification_text = "', $txt['ajax_in_progress'], '";
		var ajax_notification_cancel_text = "', $txt['modify_cancel'], '";
		
	// ]]></script>
	
	<title>', $context['page_title_html_safe'], '</title>';

	// Please don't index these Mr Robot.
	if (!empty($context['robot_no_index']))
		echo '
	<meta name="robots" content="noindex" />';

	// The ?rc1 part of this link is just here to make sure browsers don't cache it wrongly.
	echo '
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/style.css?rc1" />';

	echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/css/print.css?rc1" media="print" />';


	// IE7 needs some fixes for styles.
	if ($context['browser']['is_ie7'])
		echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/css/ie7.css" />';
	// ..and IE6!
	elseif ($context['browser']['is_ie6'])
		echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/css/ie6.css" />';
	// Firefox - all versions - too!
	elseif ($context['browser']['is_firefox'])
		echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/css/ff.css" />';

	// RTL languages require an additional stylesheet.
	if ($context['right_to_left'])
		echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/css/rtl.css" />';

	// Show all the relative links, such as help, search, contents, and the like.
	echo '
	<link rel="help" href="', $scripturl, '?action=help" />
	<link rel="search" href="' . $scripturl . '?action=search" />
	<link rel="contents" href="', $scripturl, '" />';
	
// If RSS feeds are enabled, advertise the presence of one.
	if (!empty($modSettings['xmlnews_enable']))
		echo '
	<link rel="alternate" type="application/rss+xml" title="', $context['forum_name_html_safe'], ' - RSS" href="', $scripturl, '?type=rss;action=.xml" />';

	// If we're viewing a topic, these should be the previous and next topics, respectively.
	if (!empty($context['current_topic']))
		echo '
	<link rel="prev" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=prev" />
	<link rel="next" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=next" />';

	// If we're in a board, or a topic for that matter, the index will be the board's index.
	if (!empty($context['current_board']))
		echo '
	<link rel="index" href="', $scripturl, '?board=', $context['current_board'], '.0" />';

	// We'll have to use the cookie to remember the header...
	if ($context['user']['is_guest'])
	{
		$options['collapse_header'] = !empty($_COOKIE['upshrink']);
		$options['collapse_header_ic'] = !empty($_COOKIE['upshrinkIC']);
	}

	// Output any remaining HTML headers. (from mods, maybe?)
	echo $context['html_headers'], '
	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
		// Create the main header object.
		var mainHeader = new smfToggle("upshrink", ', empty($options['collapse_header']) ? 'false' : 'true', ');
		mainHeader.useCookie(', $context['user']['is_guest'] ? 1 : 0, ');
		mainHeader.setOptions("collapse_header", "', $context['session_id'], '");
		mainHeader.addToggleImage("upshrink", "/upshrink.gif", "/upshrink2.gif");
		mainHeader.addTogglePanel("user_section");
		mainHeader.addTogglePanel("news_section");
	// ]]></script>';

	echo '
</head>
<body>';
}

function template_body_above()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	echo '
<div id="mainframe">';
template_vdock ();
//	echo '
//			<div class="head-l1">
//				<div class="head-r1">
//					<div class="header1">
//					</div>
//				</div> 
//			</div>';
//		
//	echo '
//			<div class="head-l">
//				<div class="head-r">
//				    <div class="header">';
//	// show the menu
//						echo' <div class="hrb"></div>';
//
//	template_the_menu (); //uncomment to return normal menu
//					echo' <div class="hrb"></div>';
//
//
//	echo '
//					</div>
//	     		</div> 
//			</div>';
//	echo '
//				<div class="head-l2">
//					<div class="head-r2">
//					    <div class="header2">
//						</div>
//	     		</div> 
//			</div>';



	echo '
			<div class="head-l1">
				<div class="head-r1">
					<div class="header1">
					</div>
				</div> 
			</div>';
		
	echo '
			<div class="head-l">
				<div class="head-r">
				    <div class="header">';
					
//echo '							  <div id="sbox">
//			    <form action="', $scripturl, '?action=search2" method="post" accept-charset="', $context['character_set'], '">
//			    <input class="inputbox" type="text" name="search" value="', $txt['search'], '..." onfocus="this.value = \'\';" onblur="if(this.value==\'\') this.value=\'', $txt['search'], '...\';" />';
//
//			// Search within current topic?
//			if (!empty($context['current_topic']))
//			echo '
//				<input type="hidden" name="topic" value="', $context['current_topic'], '" />';
//	
//			// If we're on a certain board, limit it to this board ;).
//			elseif (!empty($context['current_board']))
//			echo '
//				<input type="hidden" name="brd[', $context['current_board'], ']" value="', $context['current_board'], '" />';
//
//			echo '
//			      </form>
//			    </div>';

					
	echo '
			<div class="clearfix"><div id="sbox">
			    <form action="', $scripturl, '?action=search2" method="post" accept-charset="', $context['character_set'], '">
			    <input class="inputbox" type="text" name="search" value="', $txt['search'], '..." onfocus="this.value = \'\';" onblur="if(this.value==\'\') this.value=\'', $txt['search'], '...\';" />';

			// Search within current topic?
			if (!empty($context['current_topic']))
			echo '
				<input type="hidden" name="topic" value="', $context['current_topic'], '" />';
	
			// If we're on a certain board, limit it to this board ;).
			elseif (!empty($context['current_board']))
			echo '
				<input type="hidden" name="brd[', $context['current_board'], ']" value="', $context['current_board'], '" />';

			echo '
			      </form></div>';
	// Show a random news item? (or you could pick one from news_lines...)
	if (!empty($settings['enable_news']))
		echo '
			<div id="random_news"><h3>', $txt['news'], ':</h3><p>', $context['random_news_line'], '</p></div>';
	else
		echo '
			<div id="random_news"></div>';
	echo '
		</div>';
					
					
	echo'
					</div>
	     		</div> 
			</div>';
	echo '
				<div class="head-l2">
					<div class="head-r2">
					    <div class="header2">
						</div>
	     		</div> 
			</div>';



//	echo '
//				<div class="head-l1">
//					<div class="head-r1">
//					    <div class="header1">';
//	echo '  
//					</div>
//				</div> 
//				</div>';

	// show the menu
	echo '
				<div class="mainhead-l">
					<div class="mainhead-r">
					    <div class="mainheader">';
						
			if ($context['user']['is_logged'])
			{
	if (!empty($context['user']['avatar'])) {
			echo '<div id="userareaavatarleft">', $context['user']['avatar']['image'], '</div>';
			echo '<div id="userareaavatarright">', $context['user']['avatar']['image'], '</div>';
			}
			}
	echo '
		<div class="logo">';
	if (empty($settings['header_logo_url']))
		 echo $context['forum_name_html_safe'];
	else
		echo ' <a href="'.$scripturl.'" title=""><img  src="', $settings['header_logo_url'], '" alt="', $context['forum_name_html_safe'], '" /></a>';
	echo ' </div>'; // logo
	echo '
						</div>
					</div> 
				</div>';
//	echo '
//				<div class="head-l2">
//					<div class="head-r2">
//					    <div class="header2">
//						</div>
//					</div> 
//				</div>';

	echo '
			<div class="head-l1">
				<div class="head-r1">
					<div class="header1">
					</div>
				</div> 
			</div>';
		
	echo '
			<div class="head-l">
				<div class="head-r">
				    <div class="header">
					<div align="center">';
					echo' <div class="hrb"></div>';
						template_userarea();
						template_forum_stats();	
					echo' <div class="hrb"></div>';

	echo '
					</div>
					</div>
	     		</div> 
			</div>';
							

	echo '
				<div class="head-l2">
					<div class="head-r2">
					    <div class="header2">
						</div>
	     		</div> 
			</div>';


	// end of header shortie
	echo '
			<div class="head-l1">
				<div class="head-r1">
					<div class="header1">
					</div>
				</div> 
			</div>';
		
	echo '
			<div class="head-l">
				<div class="head-r">
				    <div class="header">';


					// Show the navigation tree.
					theme_linktree();
	echo '
					</div>
	     		</div> 
			</div>';
	echo '
				<div class="head-l2">
					<div class="head-r2">
					    <div class="header2">
						</div>
	     		</div> 
			</div>';


	echo '
			<div class="head-l1">
				<div class="head-r1">
					<div class="header1">
					</div>
				</div> 
			</div>';
		
	echo '
			<div class="head-l">
				<div class="head-r">
				    <div class="header">';


	// The main content should go here.
	echo '
	<div id="bodyarea">';
}

function template_body_below()
{
	global $context, $settings, $options, $scripturl, $txt;
echo '	
					</div>
	     		</div> 
	     		</div> 
			</div>';
	echo '
				<div class="head-l2">
					<div class="head-r2">
					    <div class="header2">
						</div>
	     		</div> 
			</div>';
	
	
	
	echo '
			<div class="head-l1">
				<div class="head-r1">
					<div class="header1">
					</div>
				</div> 
			</div>';
		
	echo '
			<div class="head-l">
				<div class="head-r">
				    <div class="header">';	
	// Show the "Powered by" and "Valid" logos, as well as the copyright. Remember, the copyright must be somewhere!
					echo' <div class="hrb"></div>';

	echo '
	<div id="footerarea" class=" clearfix">
		<ul class="smalltext">
			<li class="copywrite">', theme_copyright(), '<div class="smalltext"><a href="http://graphicsmayhem.com">The StormFront Theme Designed By Shortie 2009</a></div></li>
			<li><a id="button_xhtml" href="http://validator.w3.org/check/referer" target="_blank" class="new_win" title="', $txt['valid_xhtml'], '"><span>XHTML</span></a></li>
			<li><a id="button_rss" href="', $scripturl , '?type=rss;action=.xml" class="new_win"><span>RSS</span></a></li>
			<li class="last"><a id="button_wap2" href="', $scripturl , '?wap2" class="new_win"><span>WAP2</span> &nbsp; </a></li>
		</ul>';

	// Show the load time?
	if ($context['show_load_time'])
		echo '
		<div class="smalltext" id="show_loadtime">', $txt['page_created'], $context['load_time'], $txt['seconds_with'], $context['load_queries'], $txt['queries'], '</div>';
echo '	
			</div>	';				echo' <div class="hrb"></div>
	     		</div> 
			</div>

	</div>';
	echo '
				<div class="head-l2">
					<div class="head-r2">
					    <div class="header2">
						</div>
	     		</div> 
			</div>';

	echo '
			<div class="head-l1">
				<div class="head-r1">
					<div class="header1">
					</div>
				</div> 
			</div>';
		
	echo '
			<div class="head-l">
				<div class="head-r">
				    <div class="header">';
	echo'
					</div>
	     		</div> 
			</div>';
	echo '
				<div class="head-l2">
					<div class="head-r2">
					    <div class="header2">
						</div>
	     		</div> 
			</div>';
//	echo '
//	</div>';
//	echo '
//	</div>';
}

function template_html_below()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	echo '
	

</div>

</body>
</html>';
}

	// Show a linktree. This is that thing that shows "My Community | General Category | General Discussion"..
function theme_linktree($force_show = false)
{
	global $context, $settings, $options, $shown_linktree;

	// If linktree is empty, just return - also allow an override.
	if (empty($context['linktree']) || (!empty($context['dont_default_linktree']) && !$force_show))
		return;

	//!!! Temporarily don't do it twice.
	if (!empty($shown_linktree))
		return;
	$shown_linktree = true;

	echo '
	<ul id="linktree">';

	// Each tree item has a URL and name. Some may have extra_before and extra_after.
	foreach ($context['linktree'] as $link_num => $tree)
	{
		echo '
		<li', ($link_num == count($context['linktree']) - 1) ? ' class="last"' : '', '>';
		// Show something before the link?
		if (isset($tree['extra_before']))
			echo $tree['extra_before'];

		// Show the link, including a URL if it should have one.
		echo $settings['linktree_link'] && isset($tree['url']) ? '
			<a href="' . $tree['url'] . '"><span>' . $tree['name'] . '</span></a>' : '<span>' . $tree['name'] .'</span>';

		// Show something after the link...?
		if (isset($tree['extra_after']))
			echo $tree['extra_after'];

		// Don't show a separator for the last one.
		if ($link_num != count($context['linktree']) - 1)
			echo '&nbsp;>';

		echo '
		</li>';
	}
	echo '
	</ul>';
}

	// Show the menu up top. Something like [home] [help] [profile] [logout]...
function template_menu()
{
	global $context, $settings, $options, $scripturl, $txt;

	echo '	

		<div class="main-menu">
			<ul>';
				foreach ($context['menu_buttons'] as $act => $button)
	 {			
				 echo '   <li><a ', $button['active_button'] ? ' class="current"' : '' , ' href="', $button['href'], '">
					         <span class="menu-left"></span>
							 <span class="menu-right">' , $button['title'], '</a>';
	//    Does this button have any subbuttons?
        if(!empty($button['sub_buttons']))
        {
            echo '
                             <div class="sub">
								 <ul>';
            foreach($button['sub_buttons'] as $sub_button)
                    echo '
                <li><a href="', $sub_button['href'], '">' , $sub_button['title'] , '</a></li>';
            echo '
                                 </ul>				 			 
							 </div>';						     
         }
		 echo' </li>';
	 }
	echo '
			</ul>
		</div>';
}

// Generate a strip of buttons.
function template_button_strip($button_strip, $direction = 'top', $custom_td = '')
{
	global $settings, $context, $txt, $scripturl;

	// Create the buttons...
	$buttons = array();
	foreach ($button_strip as $key => $value)
		if (!isset($value['test']) || !empty($context[$value['test']]))
			$buttons[] = '<a href="' . $value['url'] . '"' . (isset($value['active']) ? ' class="active"' : '') . (isset($value['custom']) ? ' ' . $value['custom'] : '') . '><span>' . $txt[$value['text']] . '</span></a>';

	if (empty($buttons))
		return '';
	// Make the last one, as easy as possible.
	$buttons[count($buttons) - 1] = str_replace('<span>', '<span class="last">', $buttons[count($buttons) - 1]);
	echo '
		<div class="buttonlist', $direction != 'top' ? '_bottom' : '', '">
			<ul class="clearfix">
				<li>', implode('</li><li>', $buttons), '</li>
			</ul>
		</div>';
}

function template_userarea()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;
	
echo '
		<div id="userarea" >';
			if ($context['user']['is_logged'])
			{
				echo '
							<b>', $txt['hello_member_ndt'], ' ', $context['user']['name'], '</b> &nbsp;';
				// Only tell them about their messages if they can read their messages!
				if ($context['allow_pm'])
					echo $txt['msg_alert_you_have'], ' <a href="', $scripturl, '?action=pm">', $context['user']['messages'], ' ', $context['user']['messages'] != 1 ? $txt['msg_alert_messages'] : $txt['message_lowercase'], '</a>', $txt['newmessages4'], ' ', $context['user']['unread_messages'], ' ', $context['user']['unread_messages'] == 1 ? $txt['newmessages0'] : $txt['newmessages1'] , '. &nbsp;[';
				echo '
								<a href="', $scripturl, '?action=unread">',$txt['show_unread_since_visit'],'</a>&nbsp;/
								<a href="', $scripturl, '?action=unreadreplies">',$txt['show_all_unread_replies'],'</a>&nbsp;/
								<a href="', $scripturl, '?action=profile;area=showposts">',$txt['ownposts2'],'</a>]<br />
								', $context['current_time'],'';
		// Is the forum in maintenance mode?
		if ($context['in_maintenance'] && $context['user']['is_admin'])
			echo '
					<li class="notice">', $txt['maintain_mode_on'], '</li>';
		// Are there any members waiting for approval?
		if (!empty($context['unapproved_members']))
			echo '
					<li>', $context['unapproved_members'] == 1 ? $txt['approve_thereis'] : $txt['approve_thereare'], ' <a href="', $scripturl, '?action=admin;area=viewmembers;sa=browse;type=approve">', $context['unapproved_members'] == 1 ? $txt['approve_member'] : $context['unapproved_members'] . ' ' . $txt['approve_members'], '</a> ', $txt['approve_members_waiting'], '</li>';

		// Show the total time logged in?
		if (!empty($context['user']['total_time_logged_in']))
		{
			echo '
					<ul><li>', $txt['totalTimeLogged1'];
			// If days is just zero, don't bother to show it.
			if ($context['user']['total_time_logged_in']['days'] > 0)
				echo $context['user']['total_time_logged_in']['days'] . $txt['totalTimeLogged2'];
			// Same with hours - only show it if it's above zero.
			if ($context['user']['total_time_logged_in']['hours'] > 0)
				echo $context['user']['total_time_logged_in']['hours'] . $txt['totalTimeLogged3'];
			// But, let's always show minutes - Time wasted here: 0 minutes ;).
			echo $context['user']['total_time_logged_in']['minutes'], $txt['totalTimeLogged4'], '
					</li>';
		}
		if (!empty($context['open_mod_reports']) && $context['show_open_reports'])
			echo '
					<li><a href="', $scripturl, '?action=moderate;area=reports">', sprintf($txt['mod_reports_waiting'], $context['open_mod_reports']), '</a></li>';
		echo '
				</ul>';
			}
			// Otherwise they're a guest - this time ask them to either register or login - lazy bums...
	else
	{
		echo '
				<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/scripts/sha1.js"></script>
				<form class="smalltext" id="guest_form" action="', $scripturl, '?action=login2" method="post" accept-charset="', $context['character_set'], '" ', empty($context['disable_login_hashing']) ? ' onsubmit="hashLoginPassword(this, \'' . $context['session_id'] . '\');"' : '', '>
					' , $txt['login_or_register'], '<br />
					<input type="text" name="user" size="10" />
					<input type="password" name="passwrd" size="10" />
					<select name="cookielength">
						<option value="60">', $txt['one_hour'], '</option>
						<option value="1440">', $txt['one_day'], '</option>
						<option value="10080">', $txt['one_week'], '</option>
						<option value="43200">', $txt['one_month'], '</option>
						<option value="-1" selected="selected">', $txt['forever'], '</option>
					</select>
					<input type="submit" value="', $txt['login'], '" /><br />
					', $txt['quick_login_dec'];
		if (!empty($modSettings['enableOpenID']))
			echo'
					<br />
					<input type="text" name="openid_url" id="openid_url" size="25" class="openid_login" />';
		echo '
					<input type="hidden" name="hash_passwrd" value="" />
				</form>';
	}
					echo '
		</div>';

}

function template_forum_stats ()
{
		global $context, $settings, $options, $scripturl, $txt, $modSettings;

		// Show some statistics if stat info is off.
	if ($settings['show_stats_index'])
	{
		echo '
	<div   align="center" style="font-size: 6.5pt;">';
	echo '
		', $txt['members'], ': ', $context['common_stats']['total_members'], ' &nbsp;&#8226;&nbsp; ', $txt['posts_made'], ': ', $context['common_stats']['total_posts'], ' &nbsp;&#8226;&nbsp; ', $txt['topics'], ': ', $context['common_stats']['total_topics'], '
		', ($settings['show_latest_member'] ? ' &nbsp;&#8226;&nbsp; ' . $txt['welcome_member'] . ' <b>' . $context['common_stats']['latest_member']['link'] . '</b>' . $txt['newest_member'] : '') , '
	</div>';
	}
}
	



function template_the_menu ()
{
	echo ' <table class="menu-wrapper"><tr><td> ';
	// Show the menu here, according to the menu sub template.
	template_menu();
	echo '</td></tr></table>';
}

function template_vdock ()
{
			global $context, $modSettings, $user_info, $settings, $options, $scripturl, $txt;
			
	$context['view_bookmarks'] = allowedTo('make_bookmarks');
	$context['view_downloads'] = allowedTo('downloads_view');
	$context['view_gallery'] = allowedTo('mgallery_access');

echo '
<div class="fixme">
	<div id="shortie" class="shortie">';
	
echo '
	  <a href="', $scripturl, '" title="' . $txt['gmhome'] . '" >
	  <img src="' . $settings['theme_url'] . '/images/dicons/home.png" alt="' . $txt['gmhome'] . '" />' . $txt['gmhome'] . '</a> ';



echo '
	  <a  href="', $scripturl, '?action=help" title="' . $txt['gmhelp'] . '" ><img src="' . $settings['theme_url'] . '/images/dicons/help.png" alt="' . $txt['gmhelp'] . '" />' . $txt['gmhelp'] . '</a> ';

echo '
	  <a href="', $scripturl, '?action=search" title="' . $txt['gmsearch'] . '" ><img src="' . $settings['theme_url'] . '/images/dicons/search.png" alt="' . $txt['gmsearch'] .'" />' . $txt['gmsearch'] . '</a> ';

if ($context['allow_edit_profile'])
				echo '<a href="', $scripturl, '?action=profile" title="' . $txt['gmprofile'], '" ><img src="' . $settings['theme_url'] . '/images/dicons/profile.png" alt="' . $txt['gmprofile'] .'" />' . $txt['gmprofile'], '</a>';

        
if ($context['allow_pm'])
{
	if ( $context['user']['unread_messages'] >= 1 )
	{
	echo '<a href="', $scripturl, '?action=pm" title="' . $txt['gmpmsome'], '" ><img src="' . $settings['theme_url'] . '/images/dicons/pmsome.png" alt="' . $txt['gmpmsome'] .'" />' . $txt['gmpmsome'], '</a>';
} 
else {
	echo '<a href="', $scripturl, '?action=pm" title="' . $txt['gmpmnone'], '" ><img src="' . $settings['theme_url'] . '/images/dicons/pm.png" alt="' . $txt['gmpmnone'] .'" />' . $txt['gmpmnone'], '</a>';
}
}

		if ($context['allow_memberlist'])
				echo '<a href="', $scripturl, '?action=mlist" title="' . $txt['gmmembers'], '" ><img src="' . $settings['theme_url'] . '/images/dicons/members.png" alt="' . $txt['gmmembers'] .'" />' . $txt['gmmembers'], '</a>';

if ($context['allow_calendar'])
				echo '<a href="', $scripturl, '?action=calendar" title="' . $txt['gmcal'], '" ><img src="' . $settings['theme_url'] . '/images/dicons/cal.png" alt="' . $txt['gmcal'] .'" />' . $txt['gmcal'], '</a>';

 
if ($context['allow_moderation_center'])
				echo '<a href="', $scripturl, '?action=moderate" title="' . $txt['gmmod'], '" ><img src="' . $settings['theme_url'] . '/images/dicons/moderate.png" alt="' . $txt['gmmod'] .'" />' . $txt['gmmod'], '</a>';
        
		if ($context['allow_admin'])
				echo '<a href="', $scripturl, '?action=admin" title="' . $txt['gmadmin'], '" ><img src="' . $settings['theme_url'] . '/images/dicons/admin.png" alt="' . $txt['gmadmin'] .'" />' . $txt['gmadmin'], '</a>';

		if ($context['user']['is_logged'])
				echo '<a href="', $scripturl, '?action=logout;sesc=', $context['session_id'], '" title="' . $txt['gmlogout'] .'" ><img src="' . $settings['theme_url'] . '/images/dicons/logout.png" alt="' . $txt['gmlogout'] .'" />' . $txt['gmlogout'], '</a>';
                
		 if ($context['user']['is_guest'])		  
				echo '<a href="', $scripturl, '?action=login" title="' . $txt['gmlogin'], '" ><img src="' . $settings['theme_url'] . '/images/dicons/login.png" alt="' . $txt['gmlogin'] .'" />' . $txt['gmlogin'], '</a>';
                
		  if ($context['user']['is_guest'])	
				echo '<a href="', $scripturl, '?action=register" title="' . $txt['gmreg'], '" ><img src="' . $settings['theme_url'] . '/images/dicons/reg.png" alt="' . $txt['gmreg'] .'" />' . $txt['gmreg'], '</a>';

echo'  	</div>
</div>';


}



?>